// Round Border Effect
//
// Copyright Outerspace Software, all rights reserved

string description = "This effect adds round borders to your textures.";

float4x4	WorldViewProjection;	
float4		UVBounds0 = float4(0,1,0,1);
float4		DiffuseCol;

//Tweakables
float	BorderSize = 0.05;

texture MyTexture0;
sampler MyTextureSampler0 = sampler_state{
    Texture   = (MyTexture0);
    AddressU  = CLAMP;
    AddressV  = CLAMP;
    MipFilter = LINEAR;
    MinFilter = LINEAR;
    MagFilter = LINEAR;
};

struct VS_INPUT{
	float4 position:	POSITION;
	float3 normal:		NORMAL;
	float3 diffuse:		COLOR;
	float2 tex:			TEXCOORD0;
};

struct VS_OUTPUT{
	float4 position:	POSITION;
	float2 tex:			TEXCOORD0;
};

struct PS_OUTPUT{
    float4 color:		COLOR;
};

VS_OUTPUT VS(VS_INPUT input){
	VS_OUTPUT output;      
	output.position = mul(input.position, WorldViewProjection);
	output.tex = input.tex;
	return output;
}

PS_OUTPUT PS(VS_OUTPUT input){
	PS_OUTPUT output;
	
	float2 t=input.tex;

	float dx=BorderSize;
	float dy=BorderSize;
	float c;

	c=abs(t.x-UVBounds0.x);	if(c<dx) dx=c;
	c=abs(t.x-UVBounds0.y);	if(c<dx) dx=c;
	c=abs(t.y-UVBounds0.z);	if(c<dy) dy=c;
	c=abs(t.y-UVBounds0.w);	if(c<dy) dy=c;

	float b=BorderSize;
	
	if(dx<BorderSize && dy<BorderSize){
		dx=BorderSize-dx;
		dy=BorderSize-dy;
		b=BorderSize-sqrt(dx*dx+dy*dy);
	}
	
	float a=1;	
	if(b<0) a=0; else a=1;
		
	output.color = tex2D(MyTextureSampler0, t) * (1,1,1,a) * DiffuseCol;    
	return output;
}

technique Shader
{
    pass P0
    {
		Alphablendenable	=TRUE;
		SRCBLEND			=SRCALPHA;
		DESTBLEND			=INVSRCALPHA;
		    
		VertexShader	= compile vs_1_1 VS();
		PixelShader		= compile ps_2_0 PS();
    }
}
